LocationUtils class

Constructors

LocationUtils(TIMMapService service)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
service → TIMMapService
final

Methods

moveToCurrentLocationActionWithoutSearchPOI({required void moveMapCenter(TIMCoordinate coordinate)}) → Future<TIMCoordinate?>
moveToCurrentLocationActionWithSearchPOI({required void moveMapCenter(TIMCoordinate coordinate), void onGetReverseGeoCodeSearchResult(TIMReverseGeoCodeSearchResult, bool)?}) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
poiCitySearch({required void onGetPoiCitySearchResult(List<TIMPoiInfo>?, bool), required String keyword, required String city}) → dynamic
searchPOIByCoordinate({required TIMCoordinate coordinate, required void onGetReverseGeoCodeSearchResult(TIMReverseGeoCodeSearchResult, bool)}) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

debounce(dynamic fun(String text), [Duration delay = const Duration(milliseconds: 500)]) → dynamic
getAddressByFlutter() → Future<TIMCoordinate?>
gotoAMap(dynamic longitude, dynamic latitude) → Future<bool>
AMap / 高德地图
gotoAppleMap(dynamic longitude, dynamic latitude) → Future<bool>
Apple Map / 苹果地图
gotoBaiduMap(dynamic longitude, dynamic latitude) → Future<bool>
Baidu Map / 百度地图
gotoTencentMap(dynamic longitude, dynamic latitude) → Future<bool>
Tencent Map / 腾讯地图
requestLocationPermission() → Future<bool>